@@ -1,22 +1,33 @@
-/***************************************************************************
- *   Copyright (C) 2006 by Felix Hammer   *
- *   f.hammer@web.de   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+/*****************************************************************************
+ * PokerTH - The open source texas holdem engine                             *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
+ *                                                                           *
+ * This program is free software: you can redistribute it and/or modify      *
+ * it under the terms of the GNU Affero General Public License as            *
+ * published by the Free Software Foundation, either version 3 of the        *
+ * License, or (at your option) any later version.                           *
+ *                                                                           *
+ * This program is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU Affero General Public License for more details.                       *
+ *                                                                           *
+ * You should have received a copy of the GNU Affero General Public License  *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
+ *****************************************************************************/
 #include "cleanerconfig.h"
 #include <tinyxml.h>
 
@@ -43,7 +54,7 @@ using namespace std;
 CleanerConfig::CleanerConfig()
 {
 	// !!!! Revisionsnummer der Configdefaults !!!!!
-	configRev = 8;
+	configRev = 10;
 
 	// Pfad und Dateinamen setzen
 #ifdef _WIN32
@@ -102,8 +113,6 @@ CleanerConfig::CleanerConfig()
 
 #endif
 
-	string userDir = configFileName.c_str();
-
 	ostringstream tempIntToString;
 	tempIntToString << configRev;
 
@@ -140,6 +149,7 @@ CleanerConfig::CleanerConfig()
 	badWordsList.push_back("gay");
 	badWordsList.push_back("horny");
 	badWordsList.push_back("hure");
+	badWordsList.push_back("idiot");
 	badWordsList.push_back("mistgeburt");
 	badWordsList.push_back("missgeburt");
 	badWordsList.push_back("motherfucker");
@@ -160,6 +170,15 @@ CleanerConfig::CleanerConfig()
 	badWordsList.push_back("whore");
 	configList.push_back(ConfigInfo("BadWordsList", CONFIG_TYPE_STRING_LIST, "BadWords", badWordsList));
 
+	list<string> badWordsExceptionList;
+	badWordsExceptionList.push_back("idiots end");
+	badWordsExceptionList.push_back("all-in-idiot");
+	badWordsExceptionList.push_back("all-in idiot");
+	badWordsExceptionList.push_back("allin idiot");
+	badWordsExceptionList.push_back("all in idiot");
+	configList.push_back(ConfigInfo("BadWordsException", CONFIG_TYPE_STRING_LIST, "BadWordsException", badWordsExceptionList));
+
+
 	list<string> urlStringsList;
 	urlStringsList.push_back("http://");
 	urlStringsList.push_back(".com");
@@ -507,7 +526,6 @@ list<int> CleanerConfig::readConfigIntList(string varName) const
 	}
 
 	istringstream isst;
-	string tempString;
 	int tempInt;
 	list<string>::iterator it;
 	for(it = tempStringList.begin(); it != tempStringList.end(); ++it) {
@@ -527,7 +545,6 @@ void CleanerConfig::writeConfigInt(string varName, int varCont)
 {
 
 	size_t i;
-	string tempString;
 	ostringstream intToString;
 
 	for (i=0; i<configBufferList.size(); i++) {
@@ -550,7 +567,6 @@ void CleanerConfig::writeConfigIntList(string varName, list<int> varCont)
 	for (i=0; i<configBufferList.size(); i++) {
 
 		if (configBufferList[i].name == varName) {
-			string tempString;
 			list<int>::iterator it;
 			for(it = varCont.begin(); it != varCont.end(); ++it) {
 
@@ -569,7 +585,6 @@ void CleanerConfig::writeConfigStringList(string varName, list<string> varCont)
 {
 
 	size_t i;
-	list<string> stringList;
 
 	for (i=0; i<configBufferList.size(); i++) {
 
