@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,7 +14,21 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
+
 #include "configfile.h"
 #include <qttoolsinterface.h>
 #include <core/loghelper.h>
@@ -50,7 +64,7 @@ ConfigFile::ConfigFile(char *argv0, bool readonly) : noWriteAccess(readonly)
 	myConfigState = OK;
 
 	// !!!! Revisionsnummer der Configdefaults !!!!!
-	configRev = 97;
+	configRev = 98;
 
 	//standard defaults
 	logOnOffDefault = "1";
@@ -131,7 +145,7 @@ ConfigFile::ConfigFile(char *argv0, bool readonly) : noWriteAccess(readonly)
 	tempIntToString << configRev;
 	configList.push_back(ConfigInfo("ConfigRevision", CONFIG_TYPE_INT, tempIntToString.str()));
 #ifdef ANDROID
-        configList.push_back(ConfigInfo("AppDataDir", CONFIG_TYPE_STRING, ":/android/android-data/"));
+	configList.push_back(ConfigInfo("AppDataDir", CONFIG_TYPE_STRING, ":/android/android-data/"));
 #else
 	configList.push_back(ConfigInfo("AppDataDir", CONFIG_TYPE_STRING, myQtToolsInterface->getDataPathStdString(myArgv0)));
 #endif
@@ -146,7 +160,7 @@ ConfigFile::ConfigFile(char *argv0, bool readonly) : noWriteAccess(readonly)
 	configList.push_back(ConfigInfo("ShowCardsChanceMonitor", CONFIG_TYPE_INT, "1"));
 	configList.push_back(ConfigInfo("DontTranslateInternationalPokerStringsFromStyle", CONFIG_TYPE_INT, "0"));
 	configList.push_back(ConfigInfo("DisableSplashScreenOnStartup", CONFIG_TYPE_INT, "0"));
-	configList.push_back(ConfigInfo("AccidentallyCallBlocker", CONFIG_TYPE_INT, "0"));
+	configList.push_back(ConfigInfo("AccidentallyCallBlocker", CONFIG_TYPE_INT, "1"));
 	configList.push_back(ConfigInfo("AntiPeekMode", CONFIG_TYPE_INT, "0"));
 	configList.push_back(ConfigInfo("AlternateFKeysUserActionMode", CONFIG_TYPE_INT, "0"));
 	configList.push_back(ConfigInfo("EnableBetInputFocusSwitch", CONFIG_TYPE_INT, "0"));
@@ -320,8 +334,8 @@ ConfigFile::ConfigFile(char *argv0, bool readonly) : noWriteAccess(readonly)
 				if (tmpStr) tempAppDataPath = tmpStr;
 				//if appdatapath changes directly update it here not in UpdateConfig()
 #ifdef ANDROID
-                                if(tempAppDataPath != ":/android/android-data/") {
-                                        confAppDataPath->SetAttribute("value", ":/android/android-data/");
+				if(tempAppDataPath != ":/android/android-data/") {
+					confAppDataPath->SetAttribute("value", ":/android/android-data/");
 #else
 				if(tempAppDataPath != myQtToolsInterface->getDataPathStdString(myArgv0)) {
 					confAppDataPath->SetAttribute("value", myQtToolsInterface->stringToUtf8(myQtToolsInterface->getDataPathStdString(myArgv0)));
@@ -555,12 +569,19 @@ void ConfigFile::updateConfig(ConfigState myConfigState)
 			///////// VERSION HACK SECTION ///////////////////////
 			//this is the right place for special version depending config hacks:
 			//0.9.1 - log interval needs to be set to 1 instead of 0
-			if (configRev == 95 || configRev == 96) { // this means 0.9.1 or 0.9.2
+			if (configRev >= 95 && configRev <= 98) { // this means 0.9.1 or 0.9.2 or 1.0
 				TiXmlElement * confElement2 = new TiXmlElement( "LogInterval" );
 				config->LinkEndChild( confElement2 );
 				confElement2->SetAttribute("value", 1);
 				noUpdateElemtsList.push_back("LogInterval");
 			}
+
+			if (configRev == 98) { // this means 1.0
+				TiXmlElement * confElement3 = new TiXmlElement( "CurrentCardDeckStyle" );
+				config->LinkEndChild( confElement3 );
+				confElement3->SetAttribute("value", "");
+				noUpdateElemtsList.push_back("CurrentCardDeckStyle");
+			}
 			///////// VERSION HACK SECTION ///////////////////////
 
 			TiXmlHandle oldDocHandle( &oldDoc );
@@ -697,7 +718,6 @@ list<int> ConfigFile::readConfigIntList(string varName) const
 	}
 
 	istringstream isst;
-	string tempString;
 	int tempInt;
 	list<string>::iterator it;
 	for(it = tempStringList.begin(); it != tempStringList.end(); ++it) {
@@ -734,7 +754,6 @@ void ConfigFile::writeConfigInt(string varName, int varCont)
 	boost::recursive_mutex::scoped_lock lock(m_configMutex);
 
 	size_t i;
-	string tempString;
 	ostringstream intToString;
 
 	for (i=0; i<configBufferList.size(); i++) {
@@ -757,7 +776,6 @@ void ConfigFile::writeConfigIntList(string varName, list<int> varCont)
 	for (i=0; i<configBufferList.size(); i++) {
 
 		if (configBufferList[i].name == varName) {
-			string tempString;
 			list<int>::iterator it;
 			for(it = varCont.begin(); it != varCont.end(); ++it) {
 
