@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #ifndef GAME_DEFS_H
 #define GAME_DEFS_H
@@ -28,12 +41,12 @@
 #define SQLITE_LOG          1
 #define HTML_LOG            0
 
-#define POKERTH_VERSION_MAJOR	0
-#define POKERTH_VERSION_MINOR	95
+#define POKERTH_VERSION_MAJOR	1
+#define POKERTH_VERSION_MINOR	0
 #define POKERTH_VERSION			((POKERTH_VERSION_MAJOR << 8) | POKERTH_VERSION_MINOR)
 
 #define POKERTH_BETA_REVISION	0
-#define POKERTH_BETA_RELEASE_STRING	 "0.9.5"
+#define POKERTH_BETA_RELEASE_STRING	 "1.0"
 
 #define SQLITE_LOG_VERSION		1
 
@@ -97,12 +110,29 @@ enum PlayerActionLog {
 	LOG_ACTION_WIN_SIDE_POT,// wins (side pot)
 	LOG_ACTION_SIT_OUT,     // sits out
 	LOG_ACTION_WIN_GAME,    // wins game
-	LOG_ACTION_LEFT,		// left the game
-	LOG_ACTION_KICKED,		// was kicked from
+	LOG_ACTION_LEFT,		// has left the game
+	LOG_ACTION_KICKED,		// was kicked from the game
 	LOG_ACTION_ADMIN,		// is game admin now
 	LOG_ACTION_JOIN			// has joined the game
 };
 
+#define LOG_UPLOAD_ID_SIZE		40
+#define LOG_UPLOAD_OK_STR		"OK"
+#define LOG_UPLOAD_ERROR_STR	"ERROR"
+
+enum LogUploadErrorCode {
+	LOG_UPLOAD_ERROR_NO_FILE = 1,
+	LOG_UPLOAD_ERROR_OPEN_DB = 2,
+	LOG_UPLOAD_ERROR_MAX_NUM_TOTAL = 3,
+	LOG_UPLOAD_ERROR_MAX_NUM_IP = 4,
+	LOG_UPLOAD_ERROR_FILE_SIZE = 5,
+	LOG_UPLOAD_ERROR_FILE_EXT = 6,
+	LOG_UPLOAD_ERROR_FILE_HEAD = 7,
+	LOG_UPLOAD_ERROR_ID = 8,
+	LOG_UPLOAD_ERROR_FILE_MOVE = 9,
+	LOG_UPLOAD_ERROR_INSERT_DB = 10
+};
+
 enum DenyKickPlayerReason {
 	KICK_DENIED_INVALID_STATE = 0,
 	KICK_DENIED_TOO_FEW_PLAYERS,
