@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "gamelobbydialogimpl.h"
 #include "mygamelistsortfilterproxymodel.h"
@@ -27,6 +40,7 @@
 #include "game_defs.h"
 #include <net/socket_msg.h>
 #include "mymessagedialogimpl.h"
+#include "soundevents.h"
 
 using namespace std;
 
@@ -39,17 +53,17 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 	setWindowModality(Qt::ApplicationModal);
 	setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
 #elif _WIN32
-    setWindowFlags(Qt::Dialog | Qt::WindowMinimizeButtonHint);
+	setWindowFlags(Qt::Dialog | Qt::WindowMinimizeButtonHint);
 #endif
 
-    setupUi(this);
+	setupUi(this);
 	myAppDataPath = QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str());
 
 	//wait start game message
-    waitStartGameMsgBox = new MyMessageBox(this);
+	waitStartGameMsgBox = new MyMessageBox(this);
 	waitStartGameMsgBox->setText(tr("Starting game. Please wait ..."));
 #ifndef ANDROID
-    waitStartGameMsgBox->setWindowModality(Qt::NonModal);
+	waitStartGameMsgBox->setWindowModality(Qt::NonModal);
 #endif
 #ifdef __APPLE__
 	waitStartGameMsgBox->setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
@@ -57,10 +71,10 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 	waitStartGameMsgBox->setStandardButtons(QMessageBox::NoButton);
 
 	//wait start game message for rejoin
-    waitRejoinStartGameMsgBox = new MyMessageBox(this);
+	waitRejoinStartGameMsgBox = new MyMessageBox(this);
 	waitRejoinStartGameMsgBox->setText(tr("Waiting for the start of the next hand to rejoin the game ..."));
 #ifndef ANDROID
-    waitRejoinStartGameMsgBox->setWindowModality(Qt::NonModal);
+	waitRejoinStartGameMsgBox->setWindowModality(Qt::NonModal);
 #endif
 #ifdef __APPLE__
 	waitRejoinStartGameMsgBox->setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
@@ -69,6 +83,11 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 
 	inviteOnlyInfoMsgBox = new myMessageDialogImpl(myConfig, this);
 
+	//HTML stuff
+	QString pokerthDotNet("<a href='http://www.pokerth.net'>http://www.pokerth.net</a>");
+	QString clickToRanking(QString("<a href='http://online-ranking.pokerth.net'>%1</a>").arg(tr("Click here to view the online rankings")));
+	label_pokerthDotNet->setText(pokerthDotNet);
+	label_rankings->setText(clickToRanking);
 
 	waitStartGameMsgBoxTimer = new QTimer(this);
 	waitStartGameMsgBoxTimer->setSingleShot(TRUE);
@@ -113,34 +132,47 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 	myGameListSelectionModel = treeView_GameList->selectionModel();
 
 	QStringList headerList;
-	headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P");
+	headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P") << tr("Time");
 	myGameListModel->setHorizontalHeaderLabels(headerList);
 
 #ifdef GUI_800x480
-    treeView_GameList->setColumnWidth(0,220);
-    treeView_GameList->setColumnWidth(1,65);
-    treeView_GameList->setColumnWidth(2,90);
-    treeView_GameList->setColumnWidth(3,30);
-    treeView_GameList->setColumnWidth(4,30);
+	treeView_GameList->setColumnWidth(0,200); //484px alltogether
+	treeView_GameList->setColumnWidth(1,65);
+	treeView_GameList->setColumnWidth(2,100);
+	treeView_GameList->setColumnWidth(3,20);
+	treeView_GameList->setColumnWidth(4,20);
+	treeView_GameList->setColumnWidth(5,75);
 
-    treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 22px}");
-    treeView_GameList->header()->setStyleSheet("QObject {font: bold 18px}");
+	treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 22px}");
+	treeView_GameList->header()->setStyleSheet("QObject {font: bold 18px}");
 
-    //make the scrollbars touchable for mobile guis
-    this->setStyleSheet("QScrollBar:vertical { border: 1px solid grey; background: #f0f0f0; width: 55px; margin: 1px -1px 0px 0px; } QScrollBar::handle:vertical { border-radius: 4px; border: 3px solid grey; background: LightGrey ; min-height: 60px; } QScrollBar::add-line:vertical { background: none; } QScrollBar::sub-line:vertical { background: none; } QScrollBar:up-arrow:vertical, QScrollBar::down-arrow:vertical { background: none; } QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical { background: none; }");
+	//make the scrollbars touchable for mobile guis
+	this->setStyleSheet("QScrollBar:vertical { border: 1px solid grey; background: #f0f0f0; width: 55px; margin: 1px -1px 0px 0px; } QScrollBar::handle:vertical { border-radius: 4px; border: 3px solid grey; background: LightGrey ; min-height: 60px; } QScrollBar::add-line:vertical { background: none; } QScrollBar::sub-line:vertical { background: none; } QScrollBar:up-arrow:vertical, QScrollBar::down-arrow:vertical { background: none; } QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical { background: none; }");
+
+	//remove game type in game description field to save space
+	label_gameType->hide();
+	label_typeIcon->hide();
+	label_typeText->hide();
+
+	//set colors
+	QPalette p1;
+	p1.setColor(QPalette::WindowText, this->palette().color(QPalette::Link));
+	label_StartCash->setPalette(p1);
+	label_blindsList->setPalette(p1);
+	label_blindsRaiseIntervall->setPalette(p1);
+	label_blindsRaiseMode->setPalette(p1);
+	label_GameTiming->setPalette(p1);
+	label_SmallBlind->setPalette(p1);
 
-    //remove game type in game description field to save space
-    label_gameType->hide();
-    label_typeIcon->hide();
-    label_typeText->hide();
 #else
-    treeView_GameList->setColumnWidth(0,190);
-    treeView_GameList->setColumnWidth(1,65);
-    treeView_GameList->setColumnWidth(2,65);
-    treeView_GameList->setColumnWidth(3,40);
-    treeView_GameList->setColumnWidth(4,40);
+	treeView_GameList->setColumnWidth(0,190);
+	treeView_GameList->setColumnWidth(1,55);
+	treeView_GameList->setColumnWidth(2,65);
+	treeView_GameList->setColumnWidth(3,25);
+	treeView_GameList->setColumnWidth(4,25);
+	treeView_GameList->setColumnWidth(5,30);
 
-    treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
+	treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
 #endif
 	treeView_GameList->setAutoFillBackground(TRUE);
 
@@ -211,6 +243,7 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 
 	lineEdit_searchForPlayers->installEventFilter(this);
 	lineEdit_ChatInput->installEventFilter(this);
+	this->installEventFilter(this);
 
 	clearDialog();
 
@@ -234,7 +267,7 @@ void gameLobbyDialogImpl::exec()
 	}
 
 #ifdef ANDROID
-        this->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+	this->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 #endif
 	QDialog::exec();
 
@@ -352,6 +385,9 @@ void gameLobbyDialogImpl::createGame()
 		mySession->clientCreateGame(gameData, currentGameName.toUtf8().constData(), myCreateInternetGameDialog->lineEdit_Password->text().toUtf8().constData());
 
 	}
+#ifdef ANDROID
+	this->setFocus();
+#endif
 }
 
 void gameLobbyDialogImpl::joinGame()
@@ -418,21 +454,24 @@ void gameLobbyDialogImpl::refresh(int actionID)
 		myNickListSelectionModel->clearSelection();;
 
 		QStringList headerList;
-		headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P");
+		headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P") << tr("Time");;
 		myGameListModel->setHorizontalHeaderLabels(headerList);
 
 #ifdef GUI_800x480
-        treeView_GameList->setColumnWidth(0,220);
-        treeView_GameList->setColumnWidth(1,65);
-        treeView_GameList->setColumnWidth(2,90);
-        treeView_GameList->setColumnWidth(3,30);
-        treeView_GameList->setColumnWidth(4,30);
-#else
-        treeView_GameList->setColumnWidth(0,190);
+		treeView_GameList->setColumnWidth(0,200); //484px alltogether
 		treeView_GameList->setColumnWidth(1,65);
+		treeView_GameList->setColumnWidth(2,100);
+		treeView_GameList->setColumnWidth(3,20);
+		treeView_GameList->setColumnWidth(4,20);
+		treeView_GameList->setColumnWidth(5,75);
+#else
+		treeView_GameList->setColumnWidth(0,190);
+		treeView_GameList->setColumnWidth(1,55);
 		treeView_GameList->setColumnWidth(2,65);
-		treeView_GameList->setColumnWidth(3,40);
-		treeView_GameList->setColumnWidth(4,40);
+		treeView_GameList->setColumnWidth(3,25);
+		treeView_GameList->setColumnWidth(4,25);
+		treeView_GameList->setColumnWidth(5,30);
+
 #endif
 
 		QStringList headerList2;
@@ -447,7 +486,7 @@ void gameLobbyDialogImpl::refresh(int actionID)
 	} else if(actionID == MSG_NET_GAME_CLIENT_SYNCSTART) {
 		waitStartGameMsgBoxTimer->start(2000);
 	} else if(actionID == MSG_NET_GAME_CLIENT_SYNCREJOIN) {
-//		if(this->isVisible()) { //TODO <-- does it work without isVisible???
+		//		if(this->isVisible()) { //TODO <-- does it work without isVisible???
 		//break the autoStartTimer animation
 		autoStartTimer->stop();
 		autoStartTimerOverlay->hide();
@@ -456,7 +495,7 @@ void gameLobbyDialogImpl::refresh(int actionID)
 		waitRejoinStartGameMsgBox->raise();
 		waitRejoinStartGameMsgBox->activateWindow();
 		pushButton_Leave->setDisabled(true);
-//		}
+		//		}
 	}
 }
 
@@ -552,6 +591,7 @@ void gameLobbyDialogImpl::updateGameItem(QList <QStandardItem*> itemList, unsign
 			itemList.at(2)->setBackground(QBrush(QColor(0, 255, 0, 127)));
 			itemList.at(3)->setBackground(QBrush(QColor(0, 255, 0, 127)));
 			itemList.at(4)->setBackground(QBrush(QColor(0, 255, 0, 127)));
+			itemList.at(5)->setBackground(QBrush(QColor(0, 255, 0, 127)));
 			break;
 		} else {
 			itemList.at(0)->setData( "", 16);
@@ -560,6 +600,7 @@ void gameLobbyDialogImpl::updateGameItem(QList <QStandardItem*> itemList, unsign
 			itemList.at(2)->setBackground(QBrush());
 			itemList.at(3)->setBackground(QBrush());
 			itemList.at(4)->setBackground(QBrush());
+			itemList.at(5)->setBackground(QBrush());
 		}
 		++i;
 	}
@@ -617,7 +658,14 @@ void gameLobbyDialogImpl::updateGameItem(QList <QStandardItem*> itemList, unsign
 		itemList.at(4)->setData("nonpriv", 16);
 	}
 
-	//	treeView_GameList->sortByColumn(myConfig->readConfigInt("DlgGameLobbyGameListSortingSection"), (Qt::SortOrder)myConfig->readConfigInt("DlgGameLobbyGameListSortingOrder") );
+	itemList.at(5)->setData(QString::number(info.data.playerActionTimeoutSec)+"s/"+QString::number(info.data.delayBetweenHandsSec)+"s", Qt::DisplayRole);
+	QString actionTimeOutString = QString::number(info.data.playerActionTimeoutSec);
+	if(info.data.playerActionTimeoutSec < 10) {
+		actionTimeOutString = "0"+actionTimeOutString;
+	}
+	itemList.at(5)->setData(actionTimeOutString, 16);
+
+	treeView_GameList->sortByColumn(myConfig->readConfigInt("DlgGameLobbyGameListSortingSection"), (Qt::SortOrder)myConfig->readConfigInt("DlgGameLobbyGameListSortingOrder") );
 	refreshGameStats();
 }
 
@@ -629,7 +677,8 @@ void gameLobbyDialogImpl::addGame(unsigned gameId)
 	QStandardItem *item3 = new QStandardItem();
 	QStandardItem *item4 = new QStandardItem();
 	QStandardItem *item5 = new QStandardItem();
-	itemList << item1 << item2 << item3 << item4 << item5;
+	QStandardItem *item6 = new QStandardItem();
+	itemList << item1 << item2 << item3 << item4 << item5 << item6;
 
 	myGameListModel->appendRow(itemList);
 
@@ -643,7 +692,7 @@ void gameLobbyDialogImpl::updateGameMode(unsigned gameId, int /*newMode*/)
 	while (myGameListModel->item(it)) {
 		if (myGameListModel->item(it, 0)->data(Qt::UserRole) == gameId) {
 			QList <QStandardItem*> itemList;
-			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4);
+			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4) << myGameListModel->item(it, 5);
 			updateGameItem(itemList, gameId);
 			break;
 		}
@@ -721,7 +770,7 @@ void gameLobbyDialogImpl::gameAddPlayer(unsigned gameId, unsigned playerId)
 	while (myGameListModel->item(it)) {
 		if (myGameListModel->item(it, 0)->data(Qt::UserRole) == gameId) {
 			QList <QStandardItem*> itemList;
-			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4);
+			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4)  << myGameListModel->item(it, 5);
 
 			updateGameItem(itemList, gameId);
 			break;
@@ -757,7 +806,7 @@ void gameLobbyDialogImpl::gameRemovePlayer(unsigned gameId, unsigned playerId)
 	while (myGameListModel->item(it)) {
 		if (myGameListModel->item(it, 0)->data(Qt::UserRole) == gameId) {
 			QList <QStandardItem*> itemList;
-			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4);
+			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4) << myGameListModel->item(it, 5);
 
 			updateGameItem(itemList, gameId);
 			break;
@@ -820,21 +869,23 @@ void gameLobbyDialogImpl::clearDialog()
 	pushButton_joinAnyGame->setEnabled(false);
 
 	QStringList headerList;
-	headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P");
+	headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P") << tr("Time");
 	myGameListModel->setHorizontalHeaderLabels(headerList);
 
 #ifdef GUI_800x480
-    treeView_GameList->setColumnWidth(0,220);
-    treeView_GameList->setColumnWidth(1,65);
-    treeView_GameList->setColumnWidth(2,90);
-    treeView_GameList->setColumnWidth(3,30);
-    treeView_GameList->setColumnWidth(4,30);
-#else
-    treeView_GameList->setColumnWidth(0,190);
+	treeView_GameList->setColumnWidth(0,200); //484px alltogether
 	treeView_GameList->setColumnWidth(1,65);
+	treeView_GameList->setColumnWidth(2,100);
+	treeView_GameList->setColumnWidth(3,20);
+	treeView_GameList->setColumnWidth(4,20);
+	treeView_GameList->setColumnWidth(5,75);
+#else
+	treeView_GameList->setColumnWidth(0,190);
+	treeView_GameList->setColumnWidth(1,55);
 	treeView_GameList->setColumnWidth(2,65);
-	treeView_GameList->setColumnWidth(3,40);
-	treeView_GameList->setColumnWidth(4,40);
+	treeView_GameList->setColumnWidth(3,25);
+	treeView_GameList->setColumnWidth(4,25);
+	treeView_GameList->setColumnWidth(5,30);
 #endif
 
 	pushButton_CreateGame->clearFocus();
@@ -969,9 +1020,9 @@ void gameLobbyDialogImpl::addConnectedPlayer(unsigned playerId, QString playerNa
 
 	if(this->isVisible() && inGame && myConfig->readConfigInt("PlayNetworkGameNotification")) {
 		if(treeWidget_connectedPlayers->topLevelItemCount() < treeWidget_connectedPlayers->headerItem()->data(0, Qt::UserRole).toInt()) {
-			myW->getMySDLPlayer()->playSound("playerconnected", 0);
+			myW->getMySoundEventHandler()->playSound("playerconnected", 0);
 		} else {
-			myW->getMySDLPlayer()->playSound("onlinegameready", 0);
+			myW->getMySoundEventHandler()->playSound("onlinegameready", 0);
 			showAutoStartTimer();
 		}
 	}
@@ -1295,8 +1346,8 @@ void gameLobbyDialogImpl::kickPlayer()
 		if(playerName == QString::fromUtf8(myConfig->readConfigString("MyName").c_str())) {
 			{
 				MyMessageBox::warning(this, tr("Server Error"),
-									 tr("You should not kick yourself from this game!"),
-									 QMessageBox::Close);
+									  tr("You should not kick yourself from this game!"),
+									  QMessageBox::Close);
 			}
 		} else {
 			assert(mySession);
@@ -1349,6 +1400,10 @@ bool gameLobbyDialogImpl::eventFilter(QObject *obj, QEvent *event)
 	} else if (obj == lineEdit_searchForPlayers && focusEvent->gotFocus() && lineEdit_searchForPlayers->text() == tr("search for player ...")) {
 		lineEdit_searchForPlayers->clear();
 		return QDialog::eventFilter(obj, event);
+	} else if (event->type() == QEvent::KeyPress && keyEvent->key() == Qt::Key_Back) {
+		event->ignore();
+		this->reject();
+		return false;
 	} else {
 		// pass the event on to the parent class
 		return QDialog::eventFilter(obj, event);
@@ -1489,6 +1544,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp());
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	case 1: {
@@ -1496,6 +1552,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp("open", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp());
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	case 2: {
@@ -1503,6 +1560,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp("open", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp());
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	case 3: {
@@ -1510,6 +1568,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp("open", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp("nonpriv", Qt::CaseInsensitive, QRegExp::FixedString));
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	case 4: {
@@ -1517,6 +1576,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp("open", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp("private", Qt::CaseInsensitive, QRegExp::FixedString));
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	case 5: {
@@ -1524,6 +1584,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp("open", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp("ranking", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp());
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	default:
@@ -1535,10 +1596,10 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 	writeDialogSettings(1);
 
 #ifdef GUI_800x480
-        if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 20px}");
-        else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 20px}");
+	if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 20px}");
+	else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 20px}");
 
-        treeView_GameList->header()->setStyleSheet("QObject {font: bold 18px}");
+	treeView_GameList->header()->setStyleSheet("QObject {font: bold 18px}");
 #else
 	if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
 	else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
@@ -1653,7 +1714,7 @@ void gameLobbyDialogImpl::showInfoMsgBox()
 	switch(infoMsgToShowId) {
 	case 2: {
 		inviteOnlyInfoMsgBox->setModal(false);
-		inviteOnlyInfoMsgBox->show(2, tr("You have entered a game with type \"invite-only\".\nFeel free to invite other players by right-clicking on their nick in the available players list."), tr("PokerTH - Info Message"), QPixmap(":/gfx/ktip.png"), QDialogButtonBox::Ok, true);
+		inviteOnlyInfoMsgBox->show(INFO_AFTER_JOIN_INVITE_GAME, tr("You have entered a game with type \"invite-only\".\nFeel free to invite other players by right-clicking on their nick in the available players list."), tr("PokerTH - Info Message"), QPixmap(":/gfx/ktip.png"), QDialogButtonBox::Ok, true);
 	}
 	break;
 	default:
@@ -1672,7 +1733,7 @@ void gameLobbyDialogImpl::showInvitationDialog(unsigned gameId, unsigned playerI
 		inviteDialogIsCurrentlyShown = true;
 
 		myMessageDialogImpl dialog(myConfig, this);
-		if(dialog.exec(3, tr("You have been invited to the game <b>%1</b> by <b>%2</b>.<br>Would you like to join this game?").arg(QString::fromUtf8(mySession->getClientGameInfo(gameId).name.c_str())).arg(QString::fromUtf8(mySession->getClientPlayerInfo(playerIdFrom).playerName.c_str())), tr("PokerTH - Info Message"), QPixmap(":/gfx/list_add_user_64.png"), QDialogButtonBox::Yes|QDialogButtonBox::No, false)) {
+		if(dialog.exec(JOIN_INVITE_GAME_QUESTION, tr("You have been invited to the game <b>%1</b> by <b>%2</b>.<br>Would you like to join this game?").arg(QString::fromUtf8(mySession->getClientGameInfo(gameId).name.c_str())).arg(QString::fromUtf8(mySession->getClientPlayerInfo(playerIdFrom).playerName.c_str())), tr("PokerTH - Info Message"), QPixmap(":/gfx/list_add_user_64.png"), QDialogButtonBox::Yes|QDialogButtonBox::No, false)) {
 
 			mySession->acceptGameInvitation(gameId);
 			inviteDialogIsCurrentlyShown = false;
@@ -1726,7 +1787,7 @@ void gameLobbyDialogImpl::putPlayerOnIgnoreList()
 		if(!playerIsOnIgnoreList(playerId)) {
 
 			myMessageDialogImpl dialog(myConfig, this);
-			if(dialog.exec(4, tr("You will no longer receive chat messages or game invitations from this user.<br>Do you really want to put player <b>%1</b> on your ignore list?").arg(QString::fromUtf8(mySession->getClientPlayerInfo(playerId).playerName.c_str())), tr("PokerTH - Question"), QPixmap(":/gfx/im-ban-user_64.png"), QDialogButtonBox::Yes|QDialogButtonBox::No, false ) == QDialog::Accepted) {
+			if(dialog.exec(INGNORE_PLAYER_QUESTION, tr("You will no longer receive chat messages or game invitations from this user.<br>Do you really want to put player <b>%1</b> on your ignore list?").arg(QString::fromUtf8(mySession->getClientPlayerInfo(playerId).playerName.c_str())), tr("PokerTH - Question"), QPixmap(":/gfx/im-ban-user_64.png"), QDialogButtonBox::Yes|QDialogButtonBox::No, false ) == QDialog::Accepted) {
 
 				list<std::string> playerIgnoreList = myConfig->readConfigStringList("PlayerIgnoreList");
 				playerIgnoreList.push_back(QString("%1").arg(QString::fromUtf8(mySession->getClientPlayerInfo(playerId).playerName.c_str())).toUtf8().constData());
@@ -1752,13 +1813,13 @@ void gameLobbyDialogImpl::showAutoStartTimer()
 	autoStartTimerOverlay->setGeometry(((scrollArea_gameInfos->geometry().width()-190)/2), ((scrollArea_gameInfos->geometry().height()-50)/2), 190, 50);
 
 	QString string(tr("The game will start in<br><b>%1</b> seconds.").arg(6));
-        QString fontsize;
+	QString fontsize;
 #ifdef ANDROID
-        fontsize="16px";
+	fontsize="16px";
 #else
-        fontsize="10px";
+	fontsize="10px";
 #endif
-        autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:"+fontsize+";'>"+string+"</span>");
+	autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:"+fontsize+";'>"+string+"</span>");
 	autoStartTimerCounter = 6;
 	autoStartTimer->start(1000);
 
@@ -1769,13 +1830,13 @@ void gameLobbyDialogImpl::updateAutoStartTimer()
 	--autoStartTimerCounter;
 	if(autoStartTimerCounter) {
 		QString string(tr("The game will start in<br><b>%1</b> seconds.").arg(autoStartTimerCounter));
-                QString fontsize;
+		QString fontsize;
 #ifdef ANDROID
-                fontsize="16px";
+		fontsize="16px";
 #else
-                fontsize="10px";
+		fontsize="10px";
 #endif
-                autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:"+fontsize+";'>"+string+"</span>");
+		autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:"+fontsize+";'>"+string+"</span>");
 	} else {
 		autoStartTimer->stop();
 		autoStartTimerOverlay->hide();
@@ -2103,7 +2164,7 @@ void gameLobbyDialogImpl::reportBadGameName()
 		GameInfo info(mySession->getClientGameInfo(gameId));
 
 		int ret = MyMessageBox::question(this, tr("PokerTH - Question"),
-										tr("Are you sure you want to report the game name:\n\"%1\" as inappropriate?").arg(QString::fromUtf8(info.name.c_str())), QMessageBox::Yes | QMessageBox::No);
+										 tr("Are you sure you want to report the game name:\n\"%1\" as inappropriate?").arg(QString::fromUtf8(info.name.c_str())), QMessageBox::Yes | QMessageBox::No);
 
 		if(ret == QMessageBox::Yes) {
 			mySession->reportBadGameName(gameId);
