@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,9 +14,23 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "mytimeoutlabel.h"
 #include "gametableimpl.h"
+#include "soundevents.h"
 
 using namespace std;
 
@@ -95,7 +109,7 @@ void MyTimeoutLabel::nextTimeOutAnimationFrame()
 		if(timeOutFrame > waitFrames) {
 			//play beep after waitFrames one time
 			if(isBeep && !isBeepPlayed) {
-				myW->getMySDLPlayer()->playSound("yourturn",0);
+				myW->getMySoundEventHandler()->playSound("yourturn",0);
 				isBeepPlayed = TRUE;
 			}
 			//save gfx ressources and never play more the 10 pps
