@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "joinnetworkgamedialogimpl.h"
 #include "session.h"
@@ -120,8 +133,8 @@ void joinNetworkGameDialogImpl::fillServerProfileList()
 	TiXmlDocument doc(QString::fromUtf8(myServerProfilesFile.c_str()).toStdString());
 	if(!doc.LoadFile()) {
 		MyMessageBox::warning(this, tr("Load Server-Profile-File Error"),
-							 tr("Could not load server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
-							 QMessageBox::Close);
+							  tr("Could not load server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
+							  QMessageBox::Close);
 	}
 	TiXmlHandle docHandle( &doc );
 
@@ -171,8 +184,8 @@ void joinNetworkGameDialogImpl::itemFillForm (QTreeWidgetItem* item, int /*colum
 	TiXmlDocument doc(QString::fromUtf8(myServerProfilesFile.c_str()).toStdString());
 	if(!doc.LoadFile()) {
 		MyMessageBox::warning(this, tr("Load Server-Profile-File Error"),
-							 tr("Could not load server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
-							 QMessageBox::Close);
+							  tr("Could not load server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
+							  QMessageBox::Close);
 	}
 	TiXmlHandle docHandle( &doc );
 
@@ -198,8 +211,8 @@ void joinNetworkGameDialogImpl::saveServerProfile()
 	TiXmlDocument doc(QString::fromUtf8(myServerProfilesFile.c_str()).toStdString());
 	if(!doc.LoadFile()) {
 		MyMessageBox::warning(this, tr("Load Server-Profile-File Error"),
-							 tr("Could not load server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
-							 QMessageBox::Close);
+							  tr("Could not load server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
+							  QMessageBox::Close);
 	}
 	TiXmlHandle docHandle( &doc );
 
@@ -210,8 +223,8 @@ void joinNetworkGameDialogImpl::saveServerProfile()
 
 		if( testProfile ) {
 			// Wenn der Name schon existiert --> Überschreiben?
-                        MyMessageBox msgBox(QMessageBox::Warning, tr("Save Server Profile Error"),
-							   QString(tr("A profile with the name: %1 already exists.\nWould you like to overwrite ?")).arg(lineEdit_profileName->text()), QMessageBox::Yes | QMessageBox::No, this);
+			MyMessageBox msgBox(QMessageBox::Warning, tr("Save Server Profile Error"),
+								QString(tr("A profile with the name: %1 already exists.\nWould you like to overwrite ?")).arg(lineEdit_profileName->text()), QMessageBox::Yes | QMessageBox::No, this);
 			switch (msgBox.exec()) {
 
 			case QMessageBox::Yes: {
@@ -249,14 +262,14 @@ void joinNetworkGameDialogImpl::saveServerProfile()
 		}
 	} else {
 		MyMessageBox::warning(this, tr("Read Server-Profile List Error"),
-							 tr("Could not read server-profiles list"),
-							 QMessageBox::Close);
+							  tr("Could not read server-profiles list"),
+							  QMessageBox::Close);
 	}
 
 	if(!doc.SaveFile()) {
 		MyMessageBox::warning(this, tr("Save Server-Profile-File Error"),
-							 tr("Could not save server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
-							 QMessageBox::Close);
+							  tr("Could not save server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
+							  QMessageBox::Close);
 	}
 
 	fillServerProfileList();
@@ -268,8 +281,8 @@ void joinNetworkGameDialogImpl::deleteServerProfile()
 	TiXmlDocument doc(QString::fromUtf8(myServerProfilesFile.c_str()).toStdString());
 	if(!doc.LoadFile()) {
 		MyMessageBox::warning(this, tr("Load Server-Profile-File Error"),
-							 tr("Could not load server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
-							 QMessageBox::Close);
+							  tr("Could not load server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
+							  QMessageBox::Close);
 	} else {
 		TiXmlHandle docHandle( &doc );
 
@@ -281,8 +294,8 @@ void joinNetworkGameDialogImpl::deleteServerProfile()
 
 		if(!doc.SaveFile()) {
 			MyMessageBox::warning(this, tr("Save Server-Profile-File Error"),
-								 tr("Could not save server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
-								 QMessageBox::Close);
+								  tr("Could not save server-profiles-file:\n"+QString::fromUtf8(myServerProfilesFile.c_str()).toAscii()),
+								  QMessageBox::Close);
 		}
 
 		//Liste Füllen
@@ -295,10 +308,11 @@ void joinNetworkGameDialogImpl::deleteServerProfile()
 void joinNetworkGameDialogImpl::keyPressEvent ( QKeyEvent * event )
 {
 
-// 	std::cout << "key" << event->key();
+#ifndef ANDROID
 	if (event->key() == 16777220) {
 		pushButton_connect->click();    //ENTER
 	}
+#endif
 }
 
 void joinNetworkGameDialogImpl::checkIp()
