@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,18 +14,28 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "settingsdialogimpl.h"
 #include "myavatarlistitem.h"
 #include "mystylelistitem.h"
 #include "gametablestylereader.h"
 #include "carddeckstylereader.h"
-
 #include "configfile.h"
-#include "guilog.h"
 #include <net/socket_startup.h>
 #include <QSet>
-
 enum StyleType { POKERTH_DISTRIBUTED_STYLE, ADDITIONAL_STYLE };
 
 using namespace std;
@@ -40,20 +50,13 @@ settingsDialogImpl::settingsDialogImpl(QWidget *parent, ConfigFile *c, selectAva
 	setupUi(this);
 
 #ifdef ANDROID
-    stackedWidget->removeWidget(page_styles);
-    stackedWidget->removeWidget(page_sound);
-    listWidget->takeItem(1);
-    listWidget->takeItem(1);
+	stackedWidget->removeWidget(page_styles);
+	listWidget->takeItem(1);
+	label_soundvol->hide();
+	label_soundVolume->hide();
+	horizontalSlider_soundVolume->hide();
 #endif
 
-	if(!SQLITE_LOG) {//temporarely remove sql log features
-		pushButton_deleteLog->hide();
-		pushButton_saveLogAs->hide();
-		pushButton_exportLogTxt->hide();
-		pushButton_exportLogHtml->hide();
-		treeWidget_logFiles->hide();
-	}
-
 	myManualBlindsOrderDialog = new manualBlindsOrderDialogImpl;
 
 	myAppDataPath = QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str());
@@ -92,7 +95,12 @@ settingsDialogImpl::settingsDialogImpl(QWidget *parent, ConfigFile *c, selectAva
 	comboBox_switchLanguage->addItem(QString(tr("Tamil")+" "+QString::fromUtf8("(தமிழ்)")),"ta");
 	comboBox_switchLanguage->addItem(QString(tr("Turkish")+" "+QString::fromUtf8("(Tϋrkçe)")),"tr");
 
+#ifdef GUI_800x480
+	connect( pushButton_ok, SIGNAL( clicked() ), this, SLOT( isAccepted() ) );
+#else
 	connect( buttonBox, SIGNAL( accepted() ), this, SLOT( isAccepted() ) );
+#endif
+
 	connect( lineEdit_HumanPlayerName, SIGNAL( textChanged( const QString &) ), this, SLOT( playerNickChanged() ) );
 	connect( lineEdit_Opponent1Name, SIGNAL( textChanged(const QString &) ), this, SLOT( playerNickChanged() ) );
 	connect( lineEdit_Opponent2Name, SIGNAL( textChanged(const QString &) ), this, SLOT( playerNickChanged() ) );
@@ -141,15 +149,9 @@ settingsDialogImpl::settingsDialogImpl(QWidget *parent, ConfigFile *c, selectAva
 	connect( pushButton_removeCardDeckStyle, SIGNAL( clicked() ), this, SLOT( removeCardDeckStyle()) );
 	connect( pushButton_internetGameRemoveIgnoredPlayer, SIGNAL( clicked()), this, SLOT( removePlayerFromIgnoredPlayersList()));
 
-	connect( pushButton_deleteLog, SIGNAL(clicked()), this, SLOT (deleteLogFile()));
-	connect( pushButton_exportLogHtml, SIGNAL(clicked()), this, SLOT (exportLogToHtml()));
-	connect( pushButton_exportLogTxt, SIGNAL(clicked()), this, SLOT (exportLogToTxt()));
-	connect( pushButton_saveLogAs, SIGNAL(clicked()), this, SLOT (saveLogFileAs()));
-	connect( treeWidget_logFiles, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)), this, SLOT(showLogFilePreview()));
-
 #ifdef GUI_800x480
-    //make the scrollbar touchable for mobile guis
-    comboBox_switchLanguage->setStyleSheet("QObject {font: 30px} QScrollBar:vertical { border: 1px solid grey; background: white; width: 60px; margin: 0px -1px 0px 0px; } QScrollBar::handle:vertical { border-radius: 3px; border: 2px solid grey; background: LightGrey ; min-height: 60px; } QScrollBar::add-line:vertical { background: none; } QScrollBar::sub-line:vertical { background: none; } QScrollBar:up-arrow:vertical, QScrollBar::down-arrow:vertical { background: none; } QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical { background: none; }");
+	//make the scrollbar touchable for mobile guis
+	comboBox_switchLanguage->setStyleSheet("QObject {font: 30px} QScrollBar:vertical { border: 1px solid grey; background: white; width: 60px; margin: 0px -1px 0px 0px; } QScrollBar::handle:vertical { border-radius: 3px; border: 2px solid grey; background: LightGrey ; min-height: 60px; } QScrollBar::add-line:vertical { background: none; } QScrollBar::sub-line:vertical { background: none; } QScrollBar:up-arrow:vertical, QScrollBar::down-arrow:vertical { background: none; } QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical { background: none; }");
 #endif
 
 }
@@ -229,11 +231,10 @@ void settingsDialogImpl::prepareDialog()
 	checkBox_useSctp->setChecked(myConfig->readConfigInt("ServerUseSctp"));
 
 	//Internet Game Settings
-	if(myConfig->readConfigInt("InternetServerConfigMode")) {
-		groupBox_manualServerConfig->setChecked(TRUE);
-	} else {
-		groupBox_automaticServerConfig->setChecked(TRUE);
-	}
+
+	checkBox_InternetServerUseSctp->hide(); //temporarely disabled until sctp support is back
+	label_whatIsSctp->hide();
+
 	lineEdit_InternetServerListAddress->setText(QString::fromUtf8(myConfig->readConfigString("InternetServerListAddress").c_str()));
 	lineEdit_InternetServerAddress->setText(QString::fromUtf8(myConfig->readConfigString("InternetServerAddress").c_str()));
 	spinBox_InternetServerPort->setValue(myConfig->readConfigInt("InternetServerPort"));
@@ -255,6 +256,11 @@ void settingsDialogImpl::prepareDialog()
 	checkBox_InetGane_AutoLeaveTheTableAfterGameFinished->setChecked(myConfig->readConfigInt("NetAutoLeaveGameAfterFinish"));
 	comboBox_internetGameType->setCurrentIndex(myConfig->readConfigInt("InternetGameType"));
 	lineEdit_internetGameName->setText(QString::fromUtf8(myConfig->readConfigString("InternetGameName").c_str()));
+	if(myConfig->readConfigInt("InternetServerConfigMode")) {
+		groupBox_manualServerConfig->setChecked(TRUE);
+	} else {
+		groupBox_automaticServerConfig->setChecked(TRUE);
+	}
 
 	std::list<std::string> playerIgnoreList = myConfig->readConfigStringList("PlayerIgnoreList");
 	std::list<std::string>::iterator it5;
@@ -288,21 +294,21 @@ void settingsDialogImpl::prepareDialog()
 #ifdef GUI_800x480
 	// 	define PokerTH default GameTableStyle for Maemo
 	treeWidget_gameTableStyles->clear();
-        QString filename;
+	QString filename;
 #ifdef MAEMO
-        filename = "defaulttablestyle_800x480.xml";
+	filename = "defaulttablestyle_800x480.xml";
 #elif ANDROID
-        filename = "android_tablestyle_800x480.xml";
+	filename = "android_tablestyle_800x480.xml";
 #endif
 	GameTableStyleReader defaultTableStyle(myConfig, this);
-        defaultTableStyle.readStyleFile(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/"+filename);
+	defaultTableStyle.readStyleFile(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/"+filename);
 	if(defaultTableStyle.getLoadedSuccessfull()) {
 		QStringList tempStringList1;
 		tempStringList1 << defaultTableStyle.getStyleDescription() << defaultTableStyle.getStyleMaintainerName();
 		MyStyleListItem *defaultTableItem = new MyStyleListItem(tempStringList1, treeWidget_gameTableStyles);
-                defaultTableItem->setData(0, 15, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/"+filename);
+		defaultTableItem->setData(0, 15, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/"+filename);
 		defaultTableItem->setData(0, 16, POKERTH_DISTRIBUTED_STYLE);
-                defaultTableItem->setData(0, Qt::ToolTipRole, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/"+filename);
+		defaultTableItem->setData(0, Qt::ToolTipRole, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/"+filename);
 		defaultTableItem->setData(2, Qt::ToolTipRole, defaultTableStyle.getMyStateToolTipInfo());
 		if(defaultTableStyle.getState()) defaultTableItem->setIcon(2, QIcon(":/gfx/emblem-important.png"));
 		else defaultTableItem->setIcon(2, QIcon(":/gfx/dialog_ok_apply.png"));
@@ -396,22 +402,23 @@ void settingsDialogImpl::prepareDialog()
 	showCurrentGameTableStylePreview();
 
 	//CARDS
-#ifdef GUI_800x480
-    // 	define PokerTH default GameTableStyle for Maemo
-    treeWidget_cardDeckStyles->clear();
-    CardDeckStyleReader defaultCardStyle(myConfig, this);
-    defaultCardStyle.readStyleFile(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default_800x480/defaultdeckstyle_800x480.xml");
-    if(defaultCardStyle.getLoadedSuccessfull()) {
-        QStringList tempStringList1;
-        tempStringList1 << defaultCardStyle.getStyleDescription() << defaultCardStyle.getStyleMaintainerName();
-        MyStyleListItem *defaultCardItem = new MyStyleListItem(tempStringList1, treeWidget_cardDeckStyles);
-        defaultCardItem->setData(0, 15, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default_800x480/defaultdeckstyle_800x480.xml");
-        defaultCardItem->setData(0, 16, POKERTH_DISTRIBUTED_STYLE);
-        defaultCardItem->setData(0, Qt::ToolTipRole, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default_800x480/defaultdeckstyle_800x480.xml");
-    }
-#else
-	//define PokerTH default CardDeck
+	// 	define PokerTH 1.0 default carddeck
 	treeWidget_cardDeckStyles->clear();
+	CardDeckStyleReader defaultCardStyle10(myConfig, this);
+	defaultCardStyle10.readStyleFile(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default_800x480/defaultdeckstyle_800x480.xml");
+	if(defaultCardStyle10.getLoadedSuccessfull()) {
+		QStringList tempStringList1;
+		tempStringList1 << defaultCardStyle10.getStyleDescription() << defaultCardStyle10.getStyleMaintainerName();
+		MyStyleListItem *defaultCardItem = new MyStyleListItem(tempStringList1, treeWidget_cardDeckStyles);
+		defaultCardItem->setData(0, 15, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default_800x480/defaultdeckstyle_800x480.xml");
+		defaultCardItem->setData(0, 16, POKERTH_DISTRIBUTED_STYLE);
+		defaultCardItem->setData(0, Qt::ToolTipRole, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default_800x480/defaultdeckstyle_800x480.xml");
+		defaultCardItem->setData(2, Qt::ToolTipRole, defaultCardStyle10.getMyStateToolTipInfo());
+		if(defaultCardStyle10.getState()) defaultCardItem->setIcon(2, QIcon(":/gfx/emblem-important.png"));
+		else defaultCardItem->setIcon(2, QIcon(":/gfx/dialog_ok_apply.png"));
+	}
+#ifndef GUI_800x480
+	//define PokerTH old default CardDeck
 	CardDeckStyleReader defaultCardStyle(myConfig, this);
 	defaultCardStyle.readStyleFile(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default/defaultdeckstyle.xml");
 	if(defaultCardStyle.getLoadedSuccessfull()) {
@@ -421,8 +428,11 @@ void settingsDialogImpl::prepareDialog()
 		defaultCardItem->setData(0, 15, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default/defaultdeckstyle.xml");
 		defaultCardItem->setData(0, 16, POKERTH_DISTRIBUTED_STYLE);
 		defaultCardItem->setData(0, Qt::ToolTipRole, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default/defaultdeckstyle.xml");
+		defaultCardItem->setData(2, Qt::ToolTipRole, defaultCardStyle.getMyStateToolTipInfo());
+		if(defaultCardStyle.getState()) defaultCardItem->setIcon(2, QIcon(":/gfx/emblem-important.png"));
+		else defaultCardItem->setIcon(2, QIcon(":/gfx/dialog_ok_apply.png"));
 	}
-	//define PokerTH default CardDeck4c
+	//define PokerTH old default CardDeck4c
 	CardDeckStyleReader default4cCardStyle(myConfig, this);
 	default4cCardStyle.readStyleFile(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default4c/default4cdeckstyle.xml");
 	if(default4cCardStyle.getLoadedSuccessfull()) {
@@ -430,8 +440,11 @@ void settingsDialogImpl::prepareDialog()
 		tempStringList1 << default4cCardStyle.getStyleDescription() << default4cCardStyle.getStyleMaintainerName();
 		MyStyleListItem *default4cCardItem = new MyStyleListItem(tempStringList1, treeWidget_cardDeckStyles);
 		default4cCardItem->setData(0, 15, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default4c/default4cdeckstyle.xml");
-        default4cCardItem->setData(0, 16, POKERTH_DISTRIBUTED_STYLE);
+		default4cCardItem->setData(0, 16, POKERTH_DISTRIBUTED_STYLE);
 		default4cCardItem->setData(0, Qt::ToolTipRole, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default4c/default4cdeckstyle.xml");
+		default4cCardItem->setData(2, Qt::ToolTipRole, default4cCardStyle.getMyStateToolTipInfo());
+		if(default4cCardStyle.getState()) default4cCardItem->setIcon(2, QIcon(":/gfx/emblem-important.png"));
+		else default4cCardItem->setIcon(2, QIcon(":/gfx/dialog_ok_apply.png"));
 	}
 #endif
 	//load secondary card styles into list (if fallback no entry)
@@ -447,6 +460,9 @@ void settingsDialogImpl::prepareDialog()
 			nextItem->setData(0, 15,QString::fromUtf8(it2->c_str()));
 			nextItem->setData(0, 16, ADDITIONAL_STYLE);
 			nextItem->setData(0, Qt::ToolTipRole,QString::fromUtf8(it2->c_str()));
+			nextItem->setData(2, Qt::ToolTipRole, nextStyle.getMyStateToolTipInfo());
+			if(nextStyle.getState()) nextItem->setIcon(2, QIcon(":/gfx/emblem-important.png"));
+			else nextItem->setIcon(2, QIcon(":/gfx/dialog_ok_apply.png"));
 			treeWidget_cardDeckStyles->addTopLevelItem(nextItem);
 		}
 	}
@@ -517,8 +533,6 @@ void settingsDialogImpl::prepareDialog()
 	spinBox_logStoreDuration->setValue(myConfig->readConfigInt("LogStoreDuration"));
 	comboBox_logInterval->setCurrentIndex(myConfig->readConfigInt("LogInterval"));
 
-	refreshLogFileList();
-
 	bool tmpHasIpv6 = socket_has_ipv6();
 	bool tmpHasSctp = socket_has_sctp();
 	checkBox_useIpv6->setEnabled(tmpHasIpv6);
@@ -584,9 +598,9 @@ void settingsDialogImpl::isAccepted()
 
 	if(checkSetPlayerNicks.count() != 10) {
 		MyMessageBox::warning(this, tr("Settings Error"),
-							 tr("The opponent names are not unique.\n"
-								"Please choose different names for each Opponent!"),
-							 QMessageBox::Ok);
+							  tr("The opponent names are not unique.\n"
+								 "Please choose different names for each Opponent!"),
+							  QMessageBox::Ok);
 		settingsCorrect = FALSE;
 	} else {
 		//save nicks and avatars
@@ -665,9 +679,9 @@ void settingsDialogImpl::isAccepted()
 			myConfig->writeConfigString("InternetServerListAddress", lineEdit_InternetServerListAddress->text().toUtf8().constData());
 		} else {
 			MyMessageBox::warning(this, tr("Settings Error"),
-								 tr("The entered server list address is not a valid URL.\n"
-									"Please enter a valid server list address!"),
-								 QMessageBox::Ok);
+								  tr("The entered server list address is not a valid URL.\n"
+									 "Please enter a valid server list address!"),
+								  QMessageBox::Ok);
 			settingsCorrect = FALSE;
 		}
 	}
@@ -727,9 +741,9 @@ void settingsDialogImpl::isAccepted()
 			myConfig->writeConfigString("FlipsideOwnFile", lineEdit_OwnFlipsideFilename->text().toUtf8().constData());
 		} else {
 			MyMessageBox::warning(this, tr("Settings Error"),
-								 tr("The entered flipside picture doesn't exist.\n"
-									"Please enter an valid picture!"),
-								 QMessageBox::Ok);
+								  tr("The entered flipside picture doesn't exist.\n"
+									 "Please enter an valid picture!"),
+								  QMessageBox::Ok);
 			settingsCorrect = FALSE;
 		}
 	}
@@ -787,9 +801,9 @@ void settingsDialogImpl::isAccepted()
 			myConfig->writeConfigString("LogDir", lineEdit_logDir->text().toUtf8().constData());
 		} else {
 			MyMessageBox::warning(this, tr("Settings Error"),
-								 tr("The log file directory doesn't exist.\n"
-									"Please select an valid directory!"),
-								 QMessageBox::Ok);
+								  tr("The log file directory doesn't exist.\n"
+									 "Please select an valid directory!"),
+								  QMessageBox::Ok);
 			settingsCorrect = FALSE;
 		}
 
@@ -817,8 +831,8 @@ void settingsDialogImpl::isAccepted()
 
 	if(languageIsChanged) {
 		MyMessageBox::information(this, tr("Language Changed"),
-								 tr("You have changed application language to %1.\nPlease restart PokerTH to load new language!").arg(comboBox_switchLanguage->itemText(changedLanguageIndex)),
-								 QMessageBox::Ok);
+								  tr("You have changed application language to %1.\nPlease restart PokerTH to load new language!").arg(comboBox_switchLanguage->itemText(changedLanguageIndex)),
+								  QMessageBox::Ok);
 	}
 
 	//Wenn alles richtig eingegeben wurde --> Dialog schließen
@@ -955,16 +969,15 @@ void settingsDialogImpl::setLogDir()
 		QDir logDir(dir);
 		if(logDir.exists()) {
 			lineEdit_logDir->setText(dir);
-			refreshLogFileList();
 			MyMessageBox::information(this, tr("Settings Information"),
-									 tr("You have changed the log file directory.\n"
-										"Please restart PokerTH to use the new directory for the log files!"),
-									 QMessageBox::Ok);
+									  tr("You have changed the log file directory.\n"
+										 "Please restart PokerTH to use the new directory for the log files!"),
+									  QMessageBox::Ok);
 		} else {
 			MyMessageBox::warning(this, tr("Settings Error"),
-								 tr("The log file directory doesn't exist.\n"
-									"Please select an valid directory!"),
-								 QMessageBox::Ok);
+								  tr("The log file directory doesn't exist.\n"
+									 "Please select an valid directory!"),
+								  QMessageBox::Ok);
 		}
 	}
 }
@@ -1065,8 +1078,8 @@ void settingsDialogImpl::setFirstSmallBlindMargin()
 	if(radioButton_manualBlindsOrder->isChecked() && !myManualBlindsList.empty()) {
 		if(spinBox_firstSmallBlind->value() > myManualBlindsList.front()) {
 			MyMessageBox::warning(this, tr("Blinds Error"),
-								 tr("The first element in your manual-blinds-list \nis smaller than current first-small-blind!\nThis first-small-blind-value will be set to maximum allowed value."),
-								 QMessageBox::Close);
+								  tr("The first element in your manual-blinds-list \nis smaller than current first-small-blind!\nThis first-small-blind-value will be set to maximum allowed value."),
+								  QMessageBox::Close);
 		}
 		spinBox_firstSmallBlind->setMaximum(myManualBlindsList.front());
 	} else {
@@ -1075,8 +1088,8 @@ void settingsDialogImpl::setFirstSmallBlindMargin()
 	if(radioButton_netManualBlindsOrder->isChecked() && !myNetManualBlindsList.empty()) {
 		if(spinBox_netFirstSmallBlind->value() > myNetManualBlindsList.front()) {
 			MyMessageBox::warning(this, tr("Blinds Error"),
-								 tr("The first element in your manual-blinds-list \nis smaller than current first-small-blind!\nThis first-small-blind-value will be set to maximum allowed value."),
-								 QMessageBox::Close);
+								  tr("The first element in your manual-blinds-list \nis smaller than current first-small-blind!\nThis first-small-blind-value will be set to maximum allowed value."),
+								  QMessageBox::Close);
 		}
 		spinBox_netFirstSmallBlind->setMaximum(myNetManualBlindsList.front());
 	} else {
@@ -1193,8 +1206,8 @@ void settingsDialogImpl::addGameTableStyle()
 
 		if(fileNameAlreadyFound) {
 			MyMessageBox::warning(this, tr("Game Table Style Error"),
-								 tr("Selected game table style file is already in the list. \nPlease select another one to add!"),
-								 QMessageBox::Ok);
+								  tr("Selected game table style file is already in the list. \nPlease select another one to add!"),
+								  QMessageBox::Ok);
 		} else {
 			GameTableStyleReader newStyle(myConfig, this);
 			newStyle.readStyleFile(fileName);
@@ -1216,8 +1229,8 @@ void settingsDialogImpl::addGameTableStyle()
 				if(newStyle.getState() != GT_STYLE_OK) newStyle.showErrorMessage();
 			} else {
 				MyMessageBox::warning(this, tr("Game Table Style File Error"),
-									 tr("Could not load game table style file correctly. \nStyle will not be placed into list!"),
-									 QMessageBox::Ok);
+									  tr("Could not load game table style file correctly. \nStyle will not be placed into list!"),
+									  QMessageBox::Ok);
 			}
 		}
 		//save current filepath
@@ -1319,8 +1332,8 @@ void settingsDialogImpl::addCardDeckStyle()
 
 		if(fileNameAlreadyFound) {
 			MyMessageBox::warning(this, tr("Card Deck Style Error"),
-								 tr("Selected card deck style file is already in the list. \nPlease select another one to add!"),
-								 QMessageBox::Ok);
+								  tr("Selected card deck style file is already in the list. \nPlease select another one to add!"),
+								  QMessageBox::Ok);
 		} else {
 			CardDeckStyleReader newStyle(myConfig, this);
 			newStyle.readStyleFile(fileName);
@@ -1331,13 +1344,21 @@ void settingsDialogImpl::addCardDeckStyle()
 				newItem->setData(0, 15,fileName);
 				newItem->setData(0, 16, ADDITIONAL_STYLE);
 				newItem->setData(0, Qt::ToolTipRole,fileName);
+				newItem->setData(2, Qt::ToolTipRole, newStyle.getMyStateToolTipInfo());
+				if(newStyle.getState() != CD_STYLE_OK) newItem->setIcon(2, QIcon(":/gfx/emblem-important.png"));
+				else newItem->setIcon(2, QIcon(":/gfx/dialog-ok-apply.png"));
+
+				qDebug() << "settings: " << newStyle.getStyleDescription() << newStyle.getState();
+				if(newStyle.getState() != CD_STYLE_OK) newStyle.showErrorMessage();
+
 				treeWidget_cardDeckStyles->addTopLevelItem(newItem);
 				treeWidget_cardDeckStyles->setCurrentItem(newItem);
 				treeWidget_cardDeckStyles->sortItems(0, Qt::AscendingOrder);
+
 			} else {
 				MyMessageBox::warning(this, tr("Card Deck Style File Error"),
-									 tr("Could not load card deck style file correctly. \nStyle will not be placed into list!"),
-									 QMessageBox::Ok);
+									  tr("Could not load card deck style file correctly. \nStyle will not be placed into list!"),
+									  QMessageBox::Ok);
 			}
 		}
 		//save current filepath
@@ -1371,124 +1392,12 @@ void settingsDialogImpl::removePlayerFromIgnoredPlayersList()
 	}
 }
 
-void settingsDialogImpl::refreshLogFileList()
-{
-	QDir logFileDir;
-	logFileDir.setPath(lineEdit_logDir->text());
-	QStringList filters;
-	filters << "*.pdb";
-	QFileInfoList dbFilesList = logFileDir.entryInfoList(filters, QDir::Files, QDir::Time);
-
-	QFileInfo currentSqliteLogFile(QString::fromStdString(myGuiLog->getMySqliteLogFileName()));
-
-	treeWidget_logFiles->clear();
-	int i;
-	for (i=0; i < dbFilesList.size(); i++) {
-
-		QTreeWidgetItem *item = new QTreeWidgetItem;
-		item->setText(0, dbFilesList.at(i).fileName());
-		item->setData(0, Qt::UserRole, dbFilesList.at(i).absoluteFilePath());
-		if(currentSqliteLogFile.fileName() == dbFilesList.at(i).fileName()) {
-			item->setData(0, Qt::BackgroundColorRole, QColor(Qt::red));
-			item->setData(0, Qt::TextColorRole, QColor(Qt::white));
-			item->setData(0, Qt::UserRole+1, "current");
-		}
-		treeWidget_logFiles->addTopLevelItem(item);
-	}
-	treeWidget_logFiles->sortItems(0, Qt::DescendingOrder);
-}
-
-void settingsDialogImpl::deleteLogFile()
-{
-	QList<QTreeWidgetItem*> selectedItemsList = treeWidget_logFiles->selectedItems();
-
-	if(!selectedItemsList.isEmpty() && !( selectedItemsList.size() == 1 && selectedItemsList.front()->data(0, Qt::UserRole+1).toString() == "current" )) {
-
-		int ret = MyMessageBox::warning(this, tr("PokerTH - Delete log files"),
-									   tr("Do you really want to delete the selected log files?"),
-									   QMessageBox::Yes | QMessageBox::No);
-
-		if(ret == QMessageBox::Yes) {
-			for (int i = 0; i < selectedItemsList.size(); ++i) {
-				if(selectedItemsList.at(i)->data(0, Qt::UserRole+1).toString() != "current") {
-
-					if(!QFile::remove(selectedItemsList.at(i)->data(0, Qt::UserRole).toString())) {
-						MyMessageBox::warning(this, "Remove log file", "PokerTH cannot remove this log file, please verify that you have write access to this file!", QMessageBox::Close );
-					}
-				}
-			}
-			refreshLogFileList();
-		}
-	}
-}
-
-void settingsDialogImpl::exportLogToHtml()
-{
-	QTreeWidgetItem* selectedItem = treeWidget_logFiles->currentItem();
-
-	if(selectedItem) {
-		QFileInfo fi(selectedItem->text(0));
-		QString fileName = QFileDialog::getSaveFileName(this, tr("Export PokerTH log file to HTML"),
-						   QDir::homePath()+"/"+fi.baseName()+".html",
-						   tr("PokerTH HTML log (*.html)"));
-
-		if(!fileName.isEmpty()) {
-			myGuiLog->exportLogPdbToHtml(selectedItem->data(0, Qt::UserRole).toString(),fileName);
-		}
-	}
-}
-
-void settingsDialogImpl::exportLogToTxt()
-{
-	QTreeWidgetItem* selectedItem = treeWidget_logFiles->currentItem();
-
-	if(selectedItem) {
-		QFileInfo fi(selectedItem->text(0));
-		QString fileName = QFileDialog::getSaveFileName(this, tr("Export PokerTH log file to plain text"),
-						   QDir::homePath()+"/"+fi.baseName()+".txt",
-						   tr("PokerTH plain text log (*.txt)"));
-
-		if(!fileName.isEmpty()) {
-			myGuiLog->exportLogPdbToTxt(selectedItem->data(0, Qt::UserRole).toString(),fileName);
-		}
-	}
-}
-
-void settingsDialogImpl::saveLogFileAs()
-{
-	QTreeWidgetItem* selectedItem = treeWidget_logFiles->currentItem();
-
-	if(selectedItem) {
-		QFileInfo fi(selectedItem->text(0));
-		QString fileName = QFileDialog::getSaveFileName(this, tr("Save PokerTH log file"),
-						   QDir::homePath()+"/"+fi.baseName()+".pdb",
-						   tr("PokerTH SQL log (*.pdb)"));
-
-		if(!fileName.isEmpty()) {
-			QFile::copy(selectedItem->data(0, Qt::UserRole).toString(), fileName);
-		}
-	}
-}
-
-void settingsDialogImpl::showLogFilePreview()
-{
-	QTreeWidgetItem* selectedItem = treeWidget_logFiles->currentItem();
-
-	if(selectedItem) {
-		myGuiLog->showLog(selectedItem->data(0, Qt::UserRole).toString(), textBrowser_logPreview);
-	}
-
-	QTextCursor cursor(textBrowser_logPreview->textCursor());
-	cursor.movePosition(QTextCursor::Start);
-	textBrowser_logPreview->setTextCursor(cursor);
-}
-
 void settingsDialogImpl::resetSettings()
 {
 	int ret = MyMessageBox::warning(this, tr("PokerTH - Settings"),
-								   tr("Attention: this will delete all your personal settings and close PokerTH!\n"
-									  "Do you really want to reset factory settings?"),
-								   QMessageBox::Yes | QMessageBox::No);
+									tr("Attention: this will delete all your personal settings and close PokerTH!\n"
+									   "Do you really want to reset factory settings?"),
+									QMessageBox::Yes | QMessageBox::No);
 	if(ret == QMessageBox::Yes) {
 		myConfig->deleteConfigFile();
 		exit(0);
@@ -1496,11 +1405,3 @@ void settingsDialogImpl::resetSettings()
 
 }
 
-void settingsDialogImpl::keyPressEvent ( QKeyEvent * event )
-{
-	if (event->key() == Qt::Key_Delete ) { /*Delete*/
-		if(treeWidget_logFiles->hasFocus()) {
-			pushButton_deleteLog->click();
-		}
-	}
-}
