@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,12 +14,26 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "startnetworkgamedialogimpl.h"
 #include "startwindowimpl.h"
 #include "session.h"
 #include "configfile.h"
 #include "chattools.h"
+#include "soundevents.h"
 #include <net/socket_msg.h>
 
 startNetworkGameDialogImpl::startNetworkGameDialogImpl(startWindowImpl *parent, ConfigFile *config)
@@ -93,9 +107,9 @@ void startNetworkGameDialogImpl::addConnectedPlayer(unsigned playerId, QString p
 
 	if(this->isVisible() && myConfig->readConfigInt("PlayNetworkGameNotification")) {
 		if(treeWidget->topLevelItemCount() < info.data.maxNumberOfPlayers) {
-			myW->getMySDLPlayer()->playSound("playerconnected", 0);
+			myW->getMySoundEventHandler()->playSound("playerconnected", 0);
 		} else {
-			myW->getMySDLPlayer()->playSound("onlinegameready", 0);
+			myW->getMySoundEventHandler()->playSound("onlinegameready", 0);
 		}
 	}
 
@@ -160,8 +174,8 @@ void startNetworkGameDialogImpl::kickPlayer()
 		if(playerName == QString::fromUtf8(myConfig->readConfigString("MyName").c_str())) {
 			{
 				MyMessageBox::warning(this, tr("Server Error"),
-									 tr("You should not kick yourself from this game!"),
-									 QMessageBox::Close);
+									  tr("You should not kick yourself from this game!"),
+									  QMessageBox::Close);
 			}
 		} else {
 			assert(mySession);
