@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "startwindowimpl.h"
 #include "playerinterface.h"
@@ -43,8 +56,16 @@
 #include "chattools.h"
 #include "serverlistdialogimpl.h"
 #include "internetgamelogindialogimpl.h"
+#include "logfiledialog.h"
 #include "guilog.h"
 
+#ifdef ANDROID
+	#ifndef ANDROID_TEST
+		#include <QPlatformNativeInterface>
+		#include <jni.h>
+	#endif
+#endif
+
 using namespace std;
 
 startWindowImpl::startWindowImpl(ConfigFile *c, Log *l)
@@ -75,40 +96,70 @@ startWindowImpl::startWindowImpl(ConfigFile *c, Log *l)
 	this->setStatusBar(0);
 
 #ifdef GUI_800x480
-    #ifdef ANDROID
-        this->menubar->hide();
-        centralwidget->setStyleSheet(".QWidget { background-image: url(:/android/android-data/gfx/gui/misc/startwindowbg_800x480.png); background-position: bottom center; background-origin: content; background-repeat: no-repeat;}");
-        this->showFullScreen();
-    #else
-//        this->menubar->setStyleSheet("QMenuBar { background-color: #4B4B4B; font-size:20px; border-width: 0px;} QMenuBar::item { color: #F0F0F0; }");
-        this->menubar->hide();
-        centralwidget->setStyleSheet(".QWidget { background-image: url(\""+myAppDataPath+"gfx/gui/misc/startwindowbg_800x480.png\"); background-position: bottom center; background-origin: content; background-repeat: no-repeat;}");
-    #endif
-        pushButtonStart_Local_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:22px; border-width: 0px;}");
-        pushButtonInternet_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:22px; border-width: 0px;}");
-        pushButton_Create_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:22px; border-width: 0px;}");
-        pushButton_Join_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:22px; border-width: 0px;}");
-        pushButton_about->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:22px; border-width: 0px;}");
-        pushButton_configure->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:22px; border-width: 0px;}");
+	#ifdef ANDROID
+		this->menubar->hide();
 
-        connect( pushButton_about, SIGNAL( clicked() ), this, SLOT( callAboutPokerthDialog() ) );
-        connect( pushButton_configure, SIGNAL( clicked() ), this, SLOT( callSettingsDialogFromStartwindow() ) );
+		//check if custom background picture for the resolution is there. Otherwise create it!
+		QString UserDataDir = QString::fromUtf8(myConfig->readConfigString("UserDataDir").c_str());
+		QDesktopWidget dw;
+		int screenWidth = dw.screenGeometry().width();
+		int screenHeight = dw.screenGeometry().height();
+		QString customStartWindowBgFileString(UserDataDir+"/startwindowbg10_"+QString::number(screenWidth)+"x"+QString::number(screenHeight)+".png");
+		QFile customStartWindowBgFile(customStartWindowBgFileString);
+		if(customStartWindowBgFile.exists()) {
+			centralwidget->setStyleSheet(".QWidget { background-image: url("+QFileInfo(customStartWindowBgFile).absoluteFilePath()+"); background-position: top center; background-origin: content; background-repeat: no-repeat;}");
+		} else {
+			//if custom bg file could not be found load the big origin file
+			centralwidget->setStyleSheet(".QWidget { background-image: url(:/android/android-data/gfx/gui/misc/startwindowbg10_mobile.png); background-position: top center; background-origin: content; background-repeat: no-repeat;}");
+		}
+		this->showFullScreen();
+
+		//TODO HACK Missing QSystemScreenSaver::setScreenSaverInhibited(TRUE)
+//		#ifndef ANDROID_TEST
+//			JavaVM *currVM = (JavaVM *)QApplication::platformNativeInterface()->nativeResourceForWidget("JavaVM", 0);
+//			JNIEnv* env;
+//			if (currVM->AttachCurrentThread(&env, NULL)<0) {
+//				qCritical()<<"AttachCurrentThread failed";
+//			} else {
+//	//			jclass jclassApplicationClass = env->FindClass("android/view/View");
+//	//			if (jclassApplicationClass) {
+//	//				env->SetStaticIntField(jclassApplicationClass, env->GetStaticFieldID(jclassApplicationClass,"KEEP_SCREEN_ON", "I"), 1);
+//	//			}
+//				currVM->DetachCurrentThread();
+//			}
+//		#endif
+	#else
+//		Maemo
+		this->menubar->hide();
+		centralwidget->setStyleSheet(".QWidget { background-image: url(\""+myAppDataPath+"gfx/gui/misc/startwindowbg10_desktop.png\"); background-position: bottom center; background-origin: content; background-repeat: no-repeat;}");
+	#endif
+	// All mobile GUI's
+	pushButtonStart_Local_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:22px; border-width: 0px;}");
+	pushButtonInternet_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:22px; border-width: 0px;}");
+	pushButton_Create_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:22px; border-width: 0px;}");
+	pushButton_Join_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:22px; border-width: 0px;}");
+	pushButton_about->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:22px; border-width: 0px;}");
+	pushButton_configure->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:22px; border-width: 0px;}");
+	pushButton_Logs->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:22px; border-width: 0px;}");
+
+	connect( pushButton_about, SIGNAL( clicked() ), this, SLOT( callAboutPokerthDialog() ) );
+	connect( pushButton_configure, SIGNAL( clicked() ), this, SLOT( callSettingsDialogFromStartwindow() ) );
 #else
-	this->menubar->setStyleSheet("QMenuBar { background-color: #4B4B4B; font-size:12px; border-width: 0px;} QMenuBar::item { color: #F0F0F0; }");
+	//Desktop
+	this->menubar->setStyleSheet("QMenuBar { background-color: #505050; font-size:12px; border-width: 0px;} QMenuBar::item { color: #FDC942; }");
+	centralwidget->setStyleSheet(".QWidget { background-image: url(\""+myAppDataPath+"gfx/gui/misc/startwindowbg10_desktop.png\"); background-position: bottom center; background-origin: content; background-repeat: no-repeat;}");
 
-	centralwidget->setStyleSheet(".QWidget { background-image: url(\""+myAppDataPath+"gfx/gui/misc/startwindowbg.png\"); background-position: bottom center; background-origin: content; background-repeat: no-repeat;}");
+	pushButtonStart_Local_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:12px; border-width: 0px;}");
+	pushButtonInternet_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:12px; border-width: 0px;}");
+	pushButton_Create_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:12px; border-width: 0px;}");
+	pushButton_Join_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:12px; border-width: 0px;}");
+	pushButton_Logs->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #505050; color: #FDC942; font-size:12px; border-width: 0px;}");
 
-	pushButtonStart_Local_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:12px; border-width: 0px;}");
-	pushButtonInternet_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:12px; border-width: 0px;}");
-	pushButton_Create_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:12px; border-width: 0px;}");
-	pushButton_Join_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:12px; border-width: 0px;}");
-
-        connect( actionAbout_PokerTH, SIGNAL( triggered() ), this, SLOT( callAboutPokerthDialog() ) );
-        connect( actionConfigure_PokerTH, SIGNAL( triggered() ), this, SLOT( callSettingsDialogFromStartwindow() ) );
+	connect( actionAbout_PokerTH, SIGNAL( triggered() ), this, SLOT( callAboutPokerthDialog() ) );
+	connect( actionConfigure_PokerTH, SIGNAL( triggered() ), this, SLOT( callSettingsDialogFromStartwindow() ) );
 
 #endif
 
-
 	// 	Dialogs
 	myNewGameDialog = new newGameDialogImpl(this, myConfig);
 	mySelectAvatarDialog = new selectAvatarDialogImpl(this, myConfig);
@@ -119,10 +170,12 @@ startWindowImpl::startWindowImpl(ConfigFile *c, Log *l)
 	myCreateNetworkGameDialog = new createNetworkGameDialogImpl(this, myConfig);
 	myAboutPokerthDialog = new aboutPokerthImpl(this, myConfig);
 	myGameLobbyDialog = new gameLobbyDialogImpl(this, myConfig);
+	myLogFileDialog = new LogFileDialog(this, myConfig);
 
 	myStartNetworkGameDialog->setMyW(myGuiInterface->getMyW());
 	myGameLobbyDialog->setMyW(myGuiInterface->getMyW());
 	mySettingsDialog->setGuiLog(myGuiLog);
+	myLogFileDialog->setGuiLog(myGuiLog);
 
 	myTimeoutDialog = new timeoutMsgBoxImpl(this);
 	myServerListDialog = new serverListDialogImpl(this, this, myConfig);
@@ -135,7 +188,8 @@ startWindowImpl::startWindowImpl(ConfigFile *c, Log *l)
 	connect( actionCreate_Network_Game, SIGNAL( triggered() ), this, SLOT( callCreateNetworkGameDialog() ) );
 	connect( pushButton_Create_Network_Game, SIGNAL( clicked() ), this, SLOT( callCreateNetworkGameDialog() ) );
 	connect( actionJoin_Network_Game, SIGNAL( triggered() ), this, SLOT( callJoinNetworkGameDialog() ) );
-        connect( pushButton_Join_Network_Game, SIGNAL( clicked() ), this, SLOT( callJoinNetworkGameDialog() ) );
+	connect( pushButton_Join_Network_Game, SIGNAL( clicked() ), this, SLOT( callJoinNetworkGameDialog() ) );
+	connect( pushButton_Logs, SIGNAL( clicked() ), this, SLOT( callLogFileDialog() ) );
 
 	connect(this, SIGNAL(signalShowClientDialog()), this, SLOT(showClientDialog()));
 
@@ -215,6 +269,9 @@ void startWindowImpl::callNewGameDialog()
 	//wenn Dialogfenster gezeigt werden soll
 	if(myConfig->readConfigInt("ShowGameSettingsDialogOnNewGame")) {
 
+#ifdef ANDROID
+		myGuiInterface->getMyW()->hide();
+#endif
 		myNewGameDialog->exec();
 		if (myNewGameDialog->result() == QDialog::Accepted ) {
 			startNewLocalGame(myNewGameDialog);
@@ -410,12 +467,11 @@ void startWindowImpl::callRejoinPossibleDialog(unsigned gameId)
 	assert(mySession);
 	GameInfo info(mySession->getClientGameInfo(gameId));*/
 
-        MyMessageBox msgBox;
+	MyMessageBox msgBox;
 	msgBox.setIcon(QMessageBox::Question);
-	msgBox.setWindowTitle("Rejoin possible!");
-//	msgBox.setText(QString("There is an existing session with the game: %1").arg(QString::fromUtf8(info.name.c_str())));
-	msgBox.setText("There is an existing session with a previous game.");
-	msgBox.setInformativeText("Do you want to rejoin this game?");
+	msgBox.setWindowTitle(tr("Rejoin possible!"));
+	msgBox.setText(tr("There is an existing session with a previous game."));
+	msgBox.setInformativeText(tr("Do you want to rejoin this game?"));
 	msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
 	msgBox.setDefaultButton(QMessageBox::Yes);
 	int ret = msgBox.exec();
@@ -507,7 +563,7 @@ void startWindowImpl::callCreateNetworkGameDialog()
 
 		myStartNetworkGameDialog->setMaxPlayerNumber(gameData.maxNumberOfPlayers);
 
-		myStartNetworkGameDialog->setWindowTitle("Start Network Game");
+		myStartNetworkGameDialog->setWindowTitle(tr("Start Network Game"));
 
 		showNetworkStartDialog();
 	}
@@ -548,7 +604,7 @@ void startWindowImpl::callJoinNetworkGameDialog()
 		} else {
 			//needed for join and ready sounds - TODO
 			//myStartNetworkGameDialog->setMaxPlayerNumber(gameData.maxNumberOfPlayers);
-			myStartNetworkGameDialog->setWindowTitle("Start Network Game");
+			myStartNetworkGameDialog->setWindowTitle(tr("Start Network Game"));
 
 			showNetworkStartDialog();
 		}
@@ -625,6 +681,11 @@ void startWindowImpl::callSettingsDialog(bool ingame)
 	}
 }
 
+void startWindowImpl::callLogFileDialog()
+{
+	myLogFileDialog->exec();
+}
+
 void startWindowImpl::showTimeoutDialog(int msgID, unsigned duration)
 {
 	if(myTimeoutDialog->isHidden()) {
@@ -649,165 +710,165 @@ void startWindowImpl::networkError(int errorID, int /*osErrorID*/)
 	hideTimeoutDialog();
 	switch (errorID) {
 	case ERR_SOCK_SERVERADDR_NOT_SET: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Server address was not set."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Server address was not set."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_INVALID_PORT: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("An invalid port was set (ports 0-1023 are not allowed)."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("An invalid port was set (ports 0-1023 are not allowed)."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_CREATION_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Could not create a socket for TCP communication."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Could not create a socket for TCP communication."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_SET_ADDR_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Could not set the IP address."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Could not set the IP address."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_SET_PORT_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Could not set the port for this type of address."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Could not set the port for this type of address."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_RESOLVE_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-                                                         tr("The server name could not be resolved."),
-                                                         QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The server name could not be resolved."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_BIND_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Bind failed - please choose a different port."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Bind failed - please choose a different port."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_LISTEN_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Internal network error: \"listen\" failed."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Internal network error: \"listen\" failed."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_ACCEPT_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Server execution was terminated."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Server execution was terminated."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_CONNECT_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-                                                         tr("Could not connect to the server."),
-                                                         QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Could not connect to the server."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_CONNECT_TIMEOUT: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Connection timed out.\nPlease check the server address.\n\nIf the server is behind a NAT-Router, make sure port forwarding has been set up on server side."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Connection timed out.\nPlease check the server address.\n\nIf the server is behind a NAT-Router, make sure port forwarding has been set up on server side."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_SELECT_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Internal network error: \"select\" failed."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Internal network error: \"select\" failed."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_SEND_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Internal network error: \"send\" failed."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Internal network error: \"send\" failed."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_RECV_FAILED: // Sometimes windows reports recv failed on close.
 	case ERR_SOCK_CONN_RESET: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("The connection to the server was lost."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The connection to the server was lost."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_CONN_EXISTS: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Internal network error: Duplicate TCP connection."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Internal network error: Duplicate TCP connection."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_INVALID_PACKET: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("An invalid network packet was received.\nPlease make sure that all players use the same version of PokerTH."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("An invalid network packet was received.\nPlease make sure that all players use the same version of PokerTH."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_INVALID_STATE: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Internal state error.\nPlease make sure that all players use the same version of PokerTH."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Internal state error.\nPlease make sure that all players use the same version of PokerTH."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_INVALID_SERVERLIST_URL:
 	case ERR_SOCK_TRANSFER_INVALID_URL: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Invalid server list URL.\nPlease correct the address in the settings."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Invalid server list URL.\nPlease correct the address in the settings."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_INVALID_SERVERLIST_XML: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("The PokerTH internet server list contains invalid data.\nIf you use a custom server list, please make sure its format is correct."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The PokerTH internet server list contains invalid data.\nIf you use a custom server list, please make sure its format is correct."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_UNZIP_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Could not unzip the PokerTH internet server list."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Could not unzip the PokerTH internet server list."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_TRANSFER_INIT_FAILED:
 	case ERR_SOCK_TRANSFER_SELECT_FAILED:
 	case ERR_SOCK_TRANSFER_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Could not download the PokerTH internet server list.\nPlease make sure you are directly connected to the internet."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Could not download the PokerTH internet server list.\nPlease make sure you are directly connected to the internet."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_SOCK_TRANSFER_OPEN_FAILED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Could not open the target file when downloading the server list."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Could not open the target file when downloading the server list."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_VERSION_NOT_SUPPORTED: {
-                MyMessageBox msgBox(QMessageBox::Warning, tr("Network Error"),
-						   tr("The PokerTH server does not support this version of the game.<br>Please go to <a href=\"http://www.pokerth.net/\" target=\"_blank\">http://www.pokerth.net</a> and download the latest version."),
-						   QMessageBox::Close, this);
+		MyMessageBox msgBox(QMessageBox::Warning, tr("Network Error"),
+							tr("The PokerTH server does not support this version of the game.<br>Please go to <a href=\"http://www.pokerth.net/\" target=\"_blank\">http://www.pokerth.net</a> and download the latest version."),
+							QMessageBox::Close, this);
 		msgBox.setTextFormat(Qt::RichText);
 		msgBox.exec();
 	}
 	break;
 	case ERR_NET_SERVER_FULL: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Sorry, this server is already full."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Sorry, this server is already full."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_INVALID_PASSWORD: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Invalid login.\nPlease check your username and password."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Invalid login.\nPlease check your username and password."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_INVALID_PASSWORD_STR: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("The password is too long. Please choose another one."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The password is too long. Please choose another one."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_PLAYER_NAME_IN_USE: {
@@ -821,122 +882,122 @@ void startWindowImpl::networkError(int errorID, int /*osErrorID*/)
 	}
 	break;
 	case ERR_NET_INVALID_GAME_NAME: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("The game name is either too short or too long. Please choose another one."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The game name is either too short or too long. Please choose another one."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_UNKNOWN_GAME: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("The game could not be found."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The game could not be found."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_INVALID_CHAT_TEXT: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("The chat text is invalid."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The chat text is invalid."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_UNKNOWN_PLAYER_ID: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("The server referred to an unknown player. Aborting."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The server referred to an unknown player. Aborting."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_NO_CURRENT_PLAYER: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Internal error: The current player could not be found."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Internal error: The current player could not be found."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_PLAYER_NOT_ACTIVE: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Internal error: The current player is not active."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Internal error: The current player is not active."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_PLAYER_KICKED: {
 		mySession->terminateNetworkClient();
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("You were kicked from the server."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("You were kicked from the server."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_PLAYER_BANNED: {
 		mySession->terminateNetworkClient();
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("You were temporarily banned from the server."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("You were temporarily banned from the server."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_PLAYER_BLOCKED: {
 		mySession->terminateNetworkClient();
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Your account is blocked indefinitely."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Your account is blocked indefinitely."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_SESSION_TIMED_OUT: {
 		mySession->terminateNetworkClient();
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Your server connection timed out due to inactivity. You are very welcome to reconnect!"),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Your server connection timed out due to inactivity. You are very welcome to reconnect!"),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_INVALID_PLAYER_COUNT: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("The client player count is invalid."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The client player count is invalid."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_TOO_MANY_MANUAL_BLINDS: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Too many manual blinds were set. Please reconfigure the manual blinds."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Too many manual blinds were set. Please reconfigure the manual blinds."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_INVALID_AVATAR_FILE:
 	case ERR_NET_WRONG_AVATAR_SIZE: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("An invalid avatar file was configured. Please choose a different avatar."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("An invalid avatar file was configured. Please choose a different avatar."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_AVATAR_TOO_LARGE: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("The selected avatar file is too large. Please choose a different avatar."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The selected avatar file is too large. Please choose a different avatar."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_INIT_BLOCKED: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("You cannot login at this time. Please try again in a few seconds."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("You cannot login at this time. Please try again in a few seconds."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_INVALID_REQUEST_ID: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("An internal avatar error occured. Please report this to an admin in the lobby chat."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("An internal avatar error occured. Please report this to an admin in the lobby chat."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_START_TIMEOUT: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("Could not start game: Synchronization failed."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("Could not start game: Synchronization failed."),
+							  QMessageBox::Close);
 	}
 	break;
 	case ERR_NET_SERVER_MAINTENANCE: {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("The server is down for maintenance. Please try again later."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("The server is down for maintenance. Please try again later."),
+							  QMessageBox::Close);
 	}
 	break;
 	default:  {
-                MyMessageBox::warning(this, tr("Network Error"),
-							 tr("An internal error occured."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Error"),
+							  tr("An internal error occured."),
+							  QMessageBox::Close);
 	}
 	}
 	// close dialogs
@@ -953,44 +1014,44 @@ void startWindowImpl::networkNotification(int notificationId)
 	hideTimeoutDialog();
 	switch (notificationId) {
 	case NTF_NET_JOIN_IP_BLOCKED: {
-                MyMessageBox::warning(this, tr("Network Notification"),
-							 tr("You cannot join this game, because another player in that game has your network address."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Notification"),
+							  tr("You cannot join this game, because another player in that game has your network address."),
+							  QMessageBox::Close);
 	}
 	break;
 	case NTF_NET_REMOVED_START_FAILED: {
 		myGameLobbyDialog->stopWaitStartGameMsgBoxTimer();
-                if(MyMessageBox::warning(this, tr("Network Notification"),
-								tr("Your connection to the server is very slow, the game had to start without you."),
-								QMessageBox::Close) == QMessageBox::Close) {
+		if(MyMessageBox::warning(this, tr("Network Notification"),
+								 tr("Your connection to the server is very slow, the game had to start without you."),
+								 QMessageBox::Close) == QMessageBox::Close) {
 			myGameLobbyDialog->hideWaitStartGameMsgBox();
 		}
 	}
 	break;
 	case NTF_NET_REMOVED_KICKED: {
-                MyMessageBox::warning(this, tr("Network Notification"),
-							 tr("You were kicked from the game."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Notification"),
+							  tr("You were kicked from the game."),
+							  QMessageBox::Close);
 	}
 	break;
 	case NTF_NET_REMOVED_GAME_FULL:
 	case NTF_NET_JOIN_GAME_FULL: {
-                MyMessageBox::warning(this, tr("Network Notification"),
-							 tr("Sorry, this game is already full."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Notification"),
+							  tr("Sorry, this game is already full."),
+							  QMessageBox::Close);
 	}
 	break;
 	case NTF_NET_REMOVED_ALREADY_RUNNING:
 	case NTF_NET_JOIN_ALREADY_RUNNING: {
-                MyMessageBox::warning(this, tr("Network Notification"),
-							 tr("Unable to join - the server has already started the game."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Notification"),
+							  tr("Unable to join - the server has already started the game."),
+							  QMessageBox::Close);
 	}
 	break;
 	case NTF_NET_JOIN_NOT_INVITED: {
-                MyMessageBox::warning(this, tr("Network Notification"),
-							 tr("This game is of type invite-only. You cannot join this game without being invited."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Notification"),
+							  tr("This game is of type invite-only. You cannot join this game without being invited."),
+							  QMessageBox::Close);
 	}
 	break;
 	case NTF_NET_JOIN_GAME_NAME_IN_USE: {
@@ -1010,27 +1071,27 @@ void startWindowImpl::networkNotification(int notificationId)
 	}
 	break;
 	case NTF_NET_REMOVED_TIMEOUT: {
-                MyMessageBox::warning(this, tr("Network Notification"),
-							 tr("Your admin state timed out due to inactivity. Feel free to create a new game!"),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Notification"),
+							  tr("Your admin state timed out due to inactivity. Feel free to create a new game!"),
+							  QMessageBox::Close);
 	}
 	break;
 	case NTF_NET_JOIN_INVALID_PASSWORD: {
-                MyMessageBox::warning(this, tr("Network Notification"),
-							 tr("Invalid password when joining the game.\nPlease reenter the password and try again."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Notification"),
+							  tr("Invalid password when joining the game.\nPlease reenter the password and try again."),
+							  QMessageBox::Close);
 	}
 	break;
 	case NTF_NET_JOIN_GUEST_FORBIDDEN: {
-                MyMessageBox::warning(this, tr("Network Notification"),
-							 tr("You cannot join this type of game as guest."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Notification"),
+							  tr("You cannot join this type of game as guest."),
+							  QMessageBox::Close);
 	}
 	break;
 	case NTF_NET_JOIN_INVALID_SETTINGS: {
-                MyMessageBox::warning(this, tr("Network Notification"),
-							 tr("The settings are invalid for this type of game."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Network Notification"),
+							  tr("The settings are invalid for this type of game."),
+							  QMessageBox::Close);
 	}
 	break;
 	case NTF_NET_NEW_RELEASE_AVAILABLE: {
@@ -1060,8 +1121,8 @@ void startWindowImpl::networkNotification(int notificationId)
 
 void startWindowImpl::networkMessage(QString msg)
 {
-        MyMessageBox msgBox(QMessageBox::Information, tr("Server Message"),
-					   msg, QMessageBox::Close, this);
+	MyMessageBox msgBox(QMessageBox::Information, tr("Server Message"),
+						msg, QMessageBox::Close, this);
 	msgBox.setTextFormat(Qt::RichText);
 	msgBox.exec();
 }
@@ -1101,8 +1162,8 @@ void startWindowImpl::networkMessage(unsigned msgId)
 		break;
 	}
 
-    MyMessageBox msgBox(QMessageBox::Information, tr("Server Message"),
-					   msgText, QMessageBox::Close, this);
+	MyMessageBox msgBox(QMessageBox::Information, tr("Server Message"),
+						msgText, QMessageBox::Close, this);
 	//    msgBox.setTextFormat(Qt::RichText);
 	msgBox.exec();
 }
