@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 
 #include <net/socket_helper.h>
@@ -57,7 +70,7 @@ struct IrcContext {
 
 void irc_auto_rename_nick(irc_session_t *session)
 {
-	IrcContext *context = (IrcContext *) irc_get_ctx(session);
+	IrcContext *context = static_cast<IrcContext *>(irc_get_ctx(session));
 
 	if (context->renameTries <= IRC_MAX_RENAME_TRIES) { // Limit number of rename tries.
 		// Automatically rename the nick on collision.
@@ -85,7 +98,7 @@ void irc_auto_rename_nick(irc_session_t *session)
 
 void irc_notify_player_list(irc_session_t *session, const char *players)
 {
-	IrcContext *context = (IrcContext *) irc_get_ctx(session);
+	IrcContext *context = static_cast<IrcContext *>(irc_get_ctx(session));
 
 	istringstream input(players);
 	string name;
@@ -98,7 +111,7 @@ void irc_notify_player_list(irc_session_t *session, const char *players)
 
 void irc_handle_server_error(irc_session_t *session, unsigned irc_error_code)
 {
-	IrcContext *context = (IrcContext *) irc_get_ctx(session);
+	IrcContext *context = static_cast<IrcContext *>(irc_get_ctx(session));
 
 	context->ircThread.GetCallback().SignalIrcServerError(irc_error_code);
 }
@@ -106,7 +119,7 @@ void irc_handle_server_error(irc_session_t *session, unsigned irc_error_code)
 void
 irc_event_connect(irc_session_t *session, const char * /*irc_event*/, const char *origin, const char ** /*params*/, unsigned /*count*/)
 {
-	IrcContext *context = (IrcContext *) irc_get_ctx(session);
+	IrcContext *context = static_cast<IrcContext *>(irc_get_ctx(session));
 
 	context->ircThread.GetCallback().SignalIrcConnect(origin);
 	irc_cmd_join(session, context->channel.c_str(), context->channelPassword.c_str());
@@ -116,7 +129,7 @@ void
 irc_event_join(irc_session_t *session, const char * /*irc_event*/, const char *origin, const char ** /*params*/, unsigned /*count*/)
 {
 	// someone joined the channel.
-	IrcContext *context = (IrcContext *) irc_get_ctx(session);
+	IrcContext *context = static_cast<IrcContext *>(irc_get_ctx(session));
 
 	if (context->nick == origin)
 		context->ircThread.GetCallback().SignalIrcSelfJoined(context->nick, context->channel);
@@ -128,7 +141,7 @@ void
 irc_event_nick(irc_session_t *session, const char * /*irc_event*/, const char *origin, const char **params, unsigned count)
 {
 	// someone changed his/her nick
-	IrcContext *context = (IrcContext *) irc_get_ctx(session);
+	IrcContext *context = static_cast<IrcContext *>(irc_get_ctx(session));
 
 	if (count && context->nick != params[0]) { // only act if this was not an auto-rename
 		if (context->nick == origin)
@@ -141,7 +154,7 @@ void
 irc_event_kick(irc_session_t *session, const char * /*irc_event*/, const char *origin, const char **params, unsigned count)
 {
 	// someone got kicked
-	IrcContext *context = (IrcContext *) irc_get_ctx(session);
+	IrcContext *context = static_cast<IrcContext *>(irc_get_ctx(session));
 
 	string byWhom(origin);
 	string who;
@@ -159,7 +172,7 @@ void
 irc_event_leave(irc_session_t *session, const char * /*irc_event*/, const char *origin, const char ** /*params*/, unsigned /*count*/)
 {
 	// someone left the channel.
-	IrcContext *context = (IrcContext *) irc_get_ctx(session);
+	IrcContext *context = static_cast<IrcContext *>(irc_get_ctx(session));
 
 	context->ircThread.GetCallback().SignalIrcPlayerLeft(origin);
 }
@@ -167,7 +180,7 @@ irc_event_leave(irc_session_t *session, const char * /*irc_event*/, const char *
 void
 irc_event_channel(irc_session_t *session, const char * /*irc_event*/, const char *origin, const char **params, unsigned count)
 {
-	IrcContext *context = (IrcContext *) irc_get_ctx(session);
+	IrcContext *context = static_cast<IrcContext *>(irc_get_ctx(session));
 
 	if (count >= 2 && boost::algorithm::iequals(context->channel, params[0])) { // check whether this message is for our channel
 		// Signal the message (if any) to GUI.
@@ -179,7 +192,7 @@ irc_event_channel(irc_session_t *session, const char * /*irc_event*/, const char
 void
 irc_event_unknown(irc_session_t *session, const char * irc_event, const char * /*origin*/, const char ** /*params*/, unsigned /*count*/)
 {
-	IrcContext *context = (IrcContext *) irc_get_ctx(session);
+	IrcContext *context = static_cast<IrcContext *>(irc_get_ctx(session));
 
 	if (boost::algorithm::iequals(irc_event, "PONG")) {
 		context->sendingBlocked = false;
